@@ -2,8 +2,8 @@ var config = {
 
   development: {
     host: "https://localhost:3000",
-    appId: "admin",
-    appKey: "next@2017",
+    appId: "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464",
+    appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
     database: {
       host: 'rdb.codeunbug.com',
       port: 28015
