@@ -16,7 +16,8 @@ var logger = require('winston');
 var fscan = require('./../common/fscan');
 const work_dir = process.cwd();
 const config = require(process.cwd() + '/config/config');
-var db = require('rethinkdbdash')(Object.assign({},config.database,{user:config.appId,password:config.appKey}));
+var dbId=config.appId.replace(/-/g,"");
+var db = require('rethinkdbdash')(Object.assign({},config.database,{db:dbId,user:config.appId,password:config.appKey}));
 var cookieParser = require('cookie-parser');
 
 module.exports = function (nylon_path) {
