@@ -33,7 +33,7 @@ module.exports = function (db) {
                 }]
             };
            // passport.callbackLogin(user,done);
-            db.db('oauth').table('users').filter(function (ff) {
+            db.table('users').filter(function (ff) {
             return ff('providers').contains(function (cc) {
                 return cc('id').eq(user.providers[0].id)
                     .and(cc('provider').eq(user.providers[0].provider))
@@ -49,7 +49,7 @@ module.exports = function (db) {
                             break;
                         }
                     }
-                    db.db('oauth').table('users').get(u.id).update(u).run().then(function (data) {
+                    db.table('users').get(u.id).update(u).run().then(function (data) {
                         //  console.log(u.id);
                         u.register = true;
                         return done(null, u);
@@ -58,7 +58,7 @@ module.exports = function (db) {
                     });
                 } else {
                     //return done(null);
-                    db.db('oauth').table('users')
+                    db.table('users')
                         .insert(user)
                         .run()
                         .then(function (result) {
